@@ -10,9 +10,17 @@ import sklearn
 from sklearn.base import is_classifier, clone
 from sklearn.model_selection._search import BaseSearchCV
 from sklearn.utils import check_random_state
-from sklearn.utils.fixes import MaskedArray
 from sklearn.utils.validation import indexable, check_is_fitted
-from sklearn.metrics.scorer import check_scoring
+
+try:
+    from sklearn.utils.fixes import MaskedArray
+except ImportError:
+    from numpy.ma import MaskedArray
+
+try:
+    from sklearn.metrics import check_scoring
+except ImportError:
+    from sklearn.metrics.scorer import check_scoring
 
 from joblib import Parallel, delayed
 
@@ -469,7 +477,7 @@ class BayesSearchCV(BaseSearchCV):
         # applicable for that candidate. Use defaultdict as each candidate may
         # not contain all the params
         param_results = defaultdict(partial(
-            MaskedArray,
+            np.ma.array,
             np.empty(n_candidates,),
             mask=True,
             dtype=object))
